LocalDataSource class

Implementation of the local data source interface using Flutter Secure Storage.

Implemented types

Constructors

LocalDataSource()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getStoredNetworkTime() Future<Result<NetworkTimeSnapshot?>>
Get the stored trusted time snapshot from local storage.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
storeNetworkTime({required DateTime networkTime, required int monotonicTimeMillis}) Future<Result<void>>
Store the trusted time snapshot in local storage.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited